@@ -16,6 +16,11 @@ class RSocketUnknownMimetype(RSocketError):
         self.mimetype_id = mimetype_id
 
 
+class RSocketUnknownAuthType(RSocketError):
+    def __init__(self, auth_type_id):
+        self.auth_type_id = auth_type_id
+
+
 class RSocketMimetypeTooLong(RSocketError):
     def __init__(self, mimetype):
         self.mimetype = mimetype
@@ -30,6 +35,11 @@ class RSocketApplicationError(RSocketError):
     pass
 
 
+class RSocketUnknownRoute(RSocketApplicationError):
+    def __init__(self, route_id: str):
+        self.route_id = route_id
+
+
 class RSocketStreamAllocationFailure(RSocketError):
     pass
 
@@ -62,5 +72,9 @@ class RSocketTransportError(RSocketError):
     pass
 
 
+class RSocketTransportClosed(RSocketError):
+    pass
+
+
 class RSocketNoAvailableTransport(RSocketError):
     pass
